@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.010;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 use Moose;
 
@@ -1563,6 +1563,11 @@ Carp::Proxy - Diagnostic delegation
 
 =head1 DESCRIPTION
 
+B<Carp::Proxy> is a framework for throwing exceptions.  The goal is to
+couple the small lexical footprint of the B<die()> statement with
+support for comprehensive error messages.  Good diagnostics pay for
+themselves; let's make them easier to produce.
+
 Error messages in Perl are commonly coded with idioms like:
 
     die 'explanation'
@@ -1615,7 +1620,7 @@ All you need for most day-to-day work is the Proxy and two methods:
     fixed()   Pre-formatted message builder method.
 
 Use B<fatal()> wherever you currently use B<die()>.  Your Handler should
-compose the diagnostic message using the L<filled()|/filled> and/or
+compose the diagnostic text using the L<filled()|/filled> and/or
 L<fixed()|/fixed> methods.
 
 =head1 SAMPLE OUTPUT
@@ -2576,7 +2581,7 @@ certainly be used to invoke peers, although it might seem like overkill.
 
 B<call()> is useful when Handlers reside in a hierarchy of packages and
 you need a full search.  B<call()> is also the only way to invoke
-L<builtin|/BUILTIN-HANDLERS:> Handlers.
+L<BUILTIN HANDLERS|/BUILTIN-HANDLERS:>.
 
     $cp->call( '*assertion_failure*', $description, \%status_vars );
 
@@ -2666,7 +2671,7 @@ Output from B<Cwd::abs_path()> is used to form the body of the Section.
 B<filled()> creates a Section.  The Section is introduced with a
 L<header()|/header> containing I<$title>.  The body of the Section is
 produced by reformatting I<$content> into paragraphs of length-limited
-lines/
+lines.
 
 If I<$title> is not supplied, or if it is undef, then the
 L<section_title|/section_title> attribute is used in its place.  If
@@ -3500,7 +3505,7 @@ B<Carp>'s B<longmess()> or B<longmess_heavy()> may prove useful.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2014 Paul Liebert.
+Copyright 2014-2015 Paul Liebert.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
